@@ -2,7 +2,7 @@ package Taint::Util;
 use base qw(Exporter);
 use XSLoader ();
 
-$VERSION   = '0.01';
+$VERSION   = '0.02';
 @EXPORT    = qw(tainted taint untaint);
 @EXPORT_OK = @EXPORT;
 
@@ -14,7 +14,7 @@ __END__
 
 =head1 NAME
 
-Taint::Util - Test and flip the taint flag on scalars without regex matches or C<eval>
+Taint::Util - Test for and flip the taint flag without regex matches or C<eval>
 
 =head1 SYNOPSIS
 
@@ -22,21 +22,23 @@ Taint::Util - Test and flip the taint flag on scalars without regex matches or C
 
     my $sv = "pis";
 
-    taint $sv; # Now tainted
+    # $sv now tainted under taint mode
+    taint $sv;
 
+    # Untaint $sv again
     untaint $sv if tainted $sv;
 
-    # $sv now untainted again
-
 =head1 DESCRIPTION
 
 Wraps perl's internal routines for checking and setting the taint flag
-and thus does not rely on regular expressions for untainting but
-flipping a flag on the scalar in-place.
+and thus does not rely on regular expressions for untainting or odd
+tricks involving C<eval> and C<kill> for checking whether data is
+tainted, instead it checks and flips a flag on the scalar in-place.
 
 Provides three functions, C<tainted> which returns a boolean
-indicating whether a scalar is tainted and C<taint> and C<untaint>
-which always return false and are no-ops if tainting is disabled.
+indicating whether a given variable is tainted and C<taint> and
+C<untaint> which always return false and are no-ops if tainting is
+disabled.
 
 =head1 EXPORTS
 
